@@ -20,7 +20,7 @@ class ShopMadeSimple extends CMSModule {
 		return $this->Lang('friendlyname');
 	}
 	function GetVersion() {
-		return '0.3.8';
+		return '0.3.9';
 	}
 	function GetAuthor() {
 		return 'Duketown';
@@ -42,9 +42,7 @@ class ShopMadeSimple extends CMSModule {
 		return true;
 	}
 	function GetAdminSection() {
-	global $CMS_VERSION;
-	if( version_compare($CMS_VERSION,'1.8','<') ) return 'extensions';
-	return 'ecommerce';
+		return 'ecommerce';
 	}
 	function GetAdminDescription() {
 		return $this->Lang('admin_description');
@@ -69,21 +67,20 @@ class ShopMadeSimple extends CMSModule {
 	function GetDependencies() {
 	}	
 	function MinimumCMSVersion() {
-		return '1.9.4';
+		return '1.10.0';
 	}
 
 	function MaximumCMSVersion()
 	{
-		return '1.10.9';
+		return '1.11.9';
 	}
 
 	function SetParameters() {
+		
 		$this->RestrictUnknownParams();
-
-		#$this->RegisterRoute('/[sS]hop[mM]ade[sS]imple\/(?P<returnid>[0-9]+)$/', array('action'=>'fe_category_list'));
-		//$this->RegisterRoute('/[sS]hop[mM]ade[sS]imple\/(?P<product_id>[0-9]+)\/(?P<returnid>[0-9]+)$/', array('action'=>'fe_product_detail'));
 		$this->RegisterRoute('/[sS]hop[mM]ade[sS]imple\/cat\/(?P<category_id>[0-9]+)\/(?P<returnid>[0-9]+)$/', array('action'=>'fe_product_list'));
-		$this->RegisterRoute('/[sS]hop[mM]ade[sS]imple\/prod\/(?P<category_id>[0-9]+)\/(?P<product_id>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/',array('action'=>'fe_product_detail'));
+		$this->RegisterRoute('/[sS]hop[mM]ade[sS]imple\/prod\/(?P<category_id>[0-9]+)\/(?P<product_id>[0-9]+)\/(?P<returnid>[0-9]+)$/',array('action'=>'fe_product_detail'));
+
 		# The top most parameter will be shown in the bottom and vice versa
 		$this->CreateParameter('start', '', $this->Lang('helpstart'));
 		$this->CreateParameter('pagenumber', '', $this->Lang('helppagenumber'));
@@ -220,6 +217,8 @@ class ShopMadeSimple extends CMSModule {
 					break;
 				case 3:
 					$srcimg = imagecreatefrompng($sourcedir.DIRECTORY_SEPARATOR.$image);
+					imagealphablending($srcimg, true);
+					imagesavealpha($srcimg, true);
 					break;
 				default:
 					return false;
@@ -408,16 +407,8 @@ class ShopMadeSimple extends CMSModule {
 
 	function FormatPrice($price) {
 		// Check if CartMS has been installed
-		global $CMS_VERSION;
-		if (version_compare($CMS_VERSION,'1.10-beta0','>') &&
-			version_compare($CMS_VERSION,'1.11','<')) {
-			$modops = cmsms()->GetModuleOperations();
-			$CartMS = $modops->get_module_instance('CartMadeSimple');
-		}
-		else {
-			$gCms = cmsms();
-			$CartMS =& $gCms->modules['CartMadeSimple']['object'];
-		}
+		$modops = cmsms()->GetModuleOperations();
+		$CartMS = $modops->get_module_instance('CartMadeSimple');
 		if ($CartMS) {
 			$decimalpositions = $CartMS->GetPreference('numberformatdecimals', 2);
 			$decimalseperator = $CartMS->GetPreference('numberformatdec_point', '.');
@@ -438,13 +429,33 @@ class ShopMadeSimple extends CMSModule {
 		return number_format($weight, $decimalpositions, $decimalseperator, $thousandseperator);
 	}	
 
+	/*---------------------------------------------------------
+	   GetHeaderHTML()
+	   This function inserts javascript (and links) into header of HTML
+	  ---------------------------------------------------------*/
+	function GetHeaderHTML()
+	{
+ 		$javascript = '';
+		// Include script so sorting of tables in backend is possible
+		$javascript .= '<script type="text/javascript" src="../modules/JQueryTools/lib/jquery.tablesorter.js"></script>'."\n";
+		$javascript .= '<link rel="stylesheet" type="text/css" href="../modules/JQueryTools/lib/css/JQueryTools.css" media="screen" />'."\n";
+		$javascript .= '<script type="text/javascript" id="js">jQuery(document).ready(function() 
+		{ 
+			jQuery(".cms_sortable")
+				.tablesorter( 
+				); 
+		} 
+		); 
+		</script>';
+
+		return $javascript;
+	}
+
 	function ImageAddToCartSource () {
 		$config = cmsms()->GetConfig();
-		//$config = $gCms->GetConfig();
 		// Prepare link with image (Feat Req#3324)
-		return $config['root_url'].DIRECTORY_SEPARATOR.'modules'.DIRECTORY_SEPARATOR.
-				$this->GetName().DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'addtocart.gif';
-
+		return cms_join_path($config['root_url'], 'modules', $this->GetName(), 
+			'images', 'addtocart.gif');
 	}
 	
 	function RebuildThumbnails($sourcedir, $type='products') {
@@ -523,16 +534,9 @@ class ShopMadeSimple extends CMSModule {
 		and after rebuild the index
 	  ---------------------------------------------------------*/
 	function SearchReindex() {
-		global $CMS_VERSION;
-		if (version_compare($CMS_VERSION,'1.10-beta0','>') &&
-			version_compare($CMS_VERSION,'1.11','<')) {
-			$modops = cmsms()->GetModuleOperations();
-			$searchmodule = $modops->get_module_instance('Search');
-		}
-		else {
-			$gCms = cmsms();
-			$searchmodule =& $gCms->modules['Search']['object'];
-		}
+
+		$modops = cmsms()->GetModuleOperations();
+		$searchmodule = $modops->get_module_instance('Search');
 		if ($searchmodule != FALSE) {
 			$db = cmsms()->GetDb();
 			// First remove all the search index entries
