@@ -102,16 +102,8 @@ class SMSProducts {
 		$product['product_id'] = $db->Insert_ID();
 
 		// Add to search index
-		global $CMS_VERSION;
-		if (version_compare($CMS_VERSION,'1.10-beta0','>') &&
-			version_compare($CMS_VERSION,'1.11','<')) {
-			$modops = cmsms()->GetModuleOperations();
-			$searchmodule = $modops->get_module_instance('Search');
-		}
-		else {
-			$gCms = cmsms();
-			$searchmodule =& $gCms->modules['Search']['object'];
-		}
+		$modops = cmsms()->GetModuleOperations();
+		$searchmodule = $modops->get_module_instance('Search');
 		if ($searchmodule != FALSE)
 		{
 			$text = $product['name'].' '.$product['description'];
@@ -192,16 +184,8 @@ class SMSProducts {
 			return false;
 		}
 		// Update search index (AddWords first deletes the old ones)
-		global $CMS_VERSION;
-		if (version_compare($CMS_VERSION,'1.10-beta0','>') &&
-			version_compare($CMS_VERSION,'1.11','<')) {
-			$modops = cmsms()->GetModuleOperations();
-			$searchmodule = $modops->get_module_instance('Search');
-		}
-		else {
-			$gCms = cmsms();
-			$searchmodule =& $gCms->modules['Search']['object'];
-		}
+		$modops = cmsms()->GetModuleOperations();
+		$searchmodule = $modops->get_module_instance('Search');
 		if ($searchmodule != FALSE)
 		{
 			if ($product['active'] == 0) {
@@ -239,16 +223,8 @@ class SMSProducts {
 			return false;
 		}
 		// Delete from search index
-		global $CMS_VERSION;
-		if (version_compare($CMS_VERSION,'1.10-beta0','>') &&
-			version_compare($CMS_VERSION,'1.11','<')) {
-			$modops = cmsms()->GetModuleOperations();
-			$searchmodule = $modops->get_module_instance('Search');
-		}
-		else {
-			$gCms = cmsms();
-			$searchmodule =& $gCms->modules['Search']['object'];
-		}
+		$modops = cmsms()->GetModuleOperations();
+		$searchmodule = $modops->get_module_instance('Search');
 		if ($searchmodule != FALSE) {
 			$searchmodule->DeleteWords($this->module->GetName(), $product['product_id'], 'product');
 		}
